@@ -16,13 +16,13 @@ class Phase(Optionizable):
     decorators = None
     _prepared = False
 
-    def __init__(self, options = {}) -> None:
+    def __init__(self, options={}) -> None:
         super().__init__(options)
         self.exportData = []
         self.exportDataStrings = []
 
     def prepare(self):
-        if(self._prepared):
+        if self._prepared:
             return
         self.logDebug("Prepare phase: " + self.name)
         self.exportData = list(map(lambda s: Data.create(s, self.project), self.exportData))
@@ -34,7 +34,7 @@ class Phase(Optionizable):
         if phaseName in self.project.config:
             for index in self.project.config[phaseName]:
                 value = self.project.config[phaseName][index]
-                self.logDebug("Overwrite Config %s for phase %s with %s"%(index, phaseName, value))
+                self.logDebug("Overwrite Config %s for phase %s with %s" % (index, phaseName, value))
                 setattr(self, index, value)
 
     def prepareConfig(self):
@@ -46,7 +46,7 @@ class Phase(Optionizable):
 
         self.decorators = []
         for decorator in self.project.decorators:
-            if(decorator.filter(self)):
+            if decorator.filter(self):
                 self.decorators.append(decorator)
 
         return self.decorators
@@ -62,7 +62,7 @@ class Phase(Optionizable):
 
     def run(self):
         phaseName = self.getId()
-        self.log("RUN phase %s: %s"%(phaseName, self.name))
+        self.log("RUN phase %s: %s" % (phaseName, self.name))
 
         def methodNotFound():
             self.logError("The current phase needs the following method defined: " + self.runMethod)
