@@ -4,7 +4,6 @@ from ..util.Optionizable import Optionizable
 from .Decorator import Decorator
 from ..util.Logger import classLogger
 
-@classLogger
 class ExportValidator(Decorator):
     phase: Phase
 
@@ -15,10 +14,9 @@ class ExportValidator(Decorator):
     def after(self, phase : Phase):
         project = phase.project
         missingDataNames = []
-        for dataName in phase.exportData:
-            dataId = project.getDataId(dataName)
-            if(not dataId in project.registeredData):
-                missingDataNames.append(dataName)
+        for data in phase.exportData:
+            if(not project.dataExists(data)):
+                missingDataNames.append(data.name)
 
         if len(missingDataNames) > 0 :
             self.logWarning("The phase %s did not export: %s"%(phase.name, missingDataNames))
